# What is integration testing?

- Test how the code works with the different types of data and db-solutions (integrations)
- Can be a bit slow
- Only some tests, probably more than for the end-to-end test-suite

## Possible examples

- Test how Cellpy loads different types of data
